@@ -2297,18 +2297,20 @@ bool Socket::setccid(socket_t so, uint8_t ccid)
 	bool supported = false;
 	
 	// maybe also not dccp socket...
-	if(getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_AVAILABLE_CCIDS, &ccids, &len) < 0)
+	if(getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_AVAILABLE_CCIDS, (char *)&ccids, &len) < 0)
 		return false;
 
 	for(unsigned pos = 0; pos < sizeof(ccids); ++pos) {
-		if(ccid == ccids[pos])
+		if(ccid == ccids[pos]) {
 			supported = true;
+			break;
+		}
 	}
 
 	if(!supported)
 		return false;
 
-	if(setsockopt(so, SOL_DCCP, DCCP_SOCKOPT_CCID, &ccid, sizeof(ccid)) < 0)
+	if(setsockopt(so, SOL_DCCP, DCCP_SOCKOPT_CCID, (char *)&ccid, sizeof(ccid)) < 0)
 		return false;
 
 	return true;
